# -*- coding: utf-8 -*-

"""
swaggerpetstore

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OAuthScopeEnum(object):

    """Implementation of the 'OAuth Scope' enum.

    OAuth 2 scopes supported by the API

    Attributes:
        READPETS: read your pets
        WRITEPETS: modify pets in your account

    """

    READPETS = 'read:pets'

    WRITEPETS = 'write:pets'
