# -*- coding: utf-8 -*-

"""
swaggerpetstore

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Status1Enum(object):

    """Implementation of the 'Status1' enum.

    Order Status

    Attributes:
        PLACED: TODO: type description here.
        APPROVED: TODO: type description here.
        DELIVERED: TODO: type description here.

    """

    PLACED = 'placed'

    APPROVED = 'approved'

    DELIVERED = 'delivered'
