# -*- coding: utf-8 -*-

"""
swaggerpetstore

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusEnum(object):

    """Implementation of the 'Status' enum.

    pet status in the store

    Attributes:
        AVAILABLE: TODO: type description here.
        PENDING: TODO: type description here.
        SOLD: TODO: type description here.

    """

    AVAILABLE = 'available'

    PENDING = 'pending'

    SOLD = 'sold'
